@@ -42,7 +42,6 @@ LockScreen::LockScreen()
     m_View->setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
     m_View->setFrameStyle(QFrame::NoFrame);
     m_View->setContentsMargins(0,0,0,0);
-    //m_View->setFixedSize(800, 480);
 
     m_WasPortrait = LsWidget::isPortrait();
     m_isDialogActive = false;
@@ -80,7 +79,10 @@ LockScreen::LockScreen()
         m_View->setAttribute(Qt::WA_Maemo5PortraitOrientation);        
     }else{
         m_View->setAttribute(Qt::WA_Maemo5AutoOrientation);
-        connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(onOrientationChanged(int)));
+        conn.connect("",
+                     MCE_SIGNAL_PATH,
+                     MCE_SIGNAL_IF,
+                     MCE_DEVICE_ORIENTATION_SIG, this, SLOT(onOrientationChanged(QDBusMessage)));
     }
 
     m_View->setAttribute(Qt::WA_Maemo5NonComposited);
@@ -114,6 +116,16 @@ void LockScreen::setHildonFlags()
 #endif
 }
 
+bool LockScreen::hide()
+{
+    if (!m_View->isVisible())
+        return false;
+
+    m_View->hide();
+    stopUpdate();
+    return true;
+}
+
 bool LockScreen::show()
 {
     if (m_View->isVisible())
@@ -121,6 +133,7 @@ bool LockScreen::show()
 
 #ifdef Q_WS_MAEMO_5
     m_View->showFullScreen();
+    setSizeAndPosition();
 #else
     m_View->show();
 #endif
@@ -139,8 +152,8 @@ LsWidget* LockScreen::createWidget(QString type, QString name)
         return new LsBattery(name);
     else if (type == "UnlockButton")
         return new LsUnlockButton(name);
-    //else if (type == "SlideToUnlockButton")
-    //    return new LsSlideToUnlock(name);
+    else if (type == "SlideToUnlockButton")
+        return new LsSlideToUnlock(name);
     else if (type == "MediaPlayPauseButton")
         return new LsMediaPlayPauseButton(name, m_Player);
     else if (type == "MediaNextButton")
@@ -159,6 +172,8 @@ LsWidget* LockScreen::createWidget(QString type, QString name)
         return new LsCommandButton(name);
     else if (type == "Notification")
         return new LsNotification(name);
+    else if (type == "Text")
+        return new LsText(name);
     return NULL;
 }
 
@@ -220,7 +235,7 @@ void LockScreen::onDisplayStateChangedSlot(QString displayState)
         stopUpdate();
     }else if (displayState == QLatin1String(MCE_DISPLAY_ON_STRING)) {
         if (m_tklockState == MCE_TK_LOCKED && !m_isDialogActive){
-            onOrientationChanged(0);
+            //onOrientationChanged(0);
             startUpdate();            
         }
     }
@@ -236,8 +251,7 @@ void LockScreen::onTkLockChanged(QString locked)
     m_tklockState = locked;
 #ifdef Q_WS_MAEMO_5
     if (locked == MCE_TK_UNLOCKED) {
-        m_View->hide();
-        stopUpdate();
+        hide();
     } else if (locked == MCE_TK_LOCKED && !m_isDialogActive) {
         if (show())
             startUpdate();
@@ -268,16 +282,14 @@ void LockScreen::onAlarmDialogStatusChanged(QDBusMessage msg)
     qDebug() << "Alarm dialog status changed" << status;
     m_isDialogActive = status == 5;
     if (m_isDialogActive){
-        m_View->hide();
-        stopUpdate();
+        hide();
     }
 }
 
 void LockScreen::onIncomingCallSlot(QDBusMessage)
 {
     qDebug() << "Incoming call";
-    m_View->hide();
-    stopUpdate();
+    hide();
 }
 #endif
 
@@ -301,11 +313,24 @@ void LockScreen::stopUpdate()
     }
 }
 
-void LockScreen::onOrientationChanged(int)
+#ifdef Q_WS_MAEMO_5
+void LockScreen::onOrientationChanged(QDBusMessage msg)
 {
+    QVariant val = msg.arguments()[0];
+    qDebug() << "onOrientationChanged:" << val.toString();
+    if (val.toString() != "portrait" && val.toString() != "landscape")
+        return;
+    LsWidget::setPortrait(val.toString() == "portrait");
+
     if (!m_View->isVisible())
         return;
 
+    setSizeAndPosition();
+}
+#endif
+
+void LockScreen::setSizeAndPosition()
+{
     bool isPortrait = LsWidget::isPortrait();
     if (m_WasPortrait != isPortrait){
         m_WasPortrait = isPortrait;
