@@ -35,6 +35,7 @@ public:
 
     static bool isLocked();
     bool show();
+    bool hide();
     static bool Debug;
 
 private:
@@ -55,14 +56,15 @@ private:
     void stopUpdate();
 
     QString m_BkgPath;
+    void setSizeAndPosition();
 
 private slots:
     LsWidget* createWidget(QString type, QString name);
     void onDisplayStateChangedSlot(QString displayState);
     void onTkLockChanged(QString locked);
     void onCallStateChanged(QString);
-    void onOrientationChanged(int);
 #ifdef Q_WS_MAEMO_5
+    void onOrientationChanged(QDBusMessage);
     void onIncomingCallSlot(QDBusMessage);
     void onAlarmDialogStatusChanged(QDBusMessage);
 #endif
