@@ -36,7 +36,7 @@ void LsMediaAlbumArt::applySettings()
 {
     setSizeAndPosition(QSize(100, 100), QPoint(0, 0));
 
-    m_NoCoverImage = getSetting("NoCoverImage", ":/images/no-album-art.png").toString();
+    m_NoCoverImage = getSetting("NoCoverImage", "/opt/qtlockscreen/default/no-album-art.png").toString();
     if (!m_NoCoverImage.isEmpty())
         m_AlbumArt = QPixmap(m_NoCoverImage).scaledToWidth(size().width());
 }
@@ -51,8 +51,8 @@ void LsMediaAlbumArt::stopUpdate()
 void LsMediaAlbumArt::startUpdate()
 {
     if (m_Player){
-        m_Player->getCurrentMetadata();
         connect(m_Player, SIGNAL(metadataChanged(QMap<QString,QVariant>)), this, SLOT(onMetadataChanged(QMap<QString,QVariant>)));
+        m_Player->getCurrentMetadata();
     }
 }
 
