@@ -18,9 +18,11 @@
 #ifndef LSSLIDETOUNLOCK_H
 #define LSSLIDETOUNLOCK_H
 #include "lswidget.h"
+#include "lsunlockslider.h"
 
-class LsSlideToUnlock : public LsWidget
+class LsSlideToUnlock : public QObject, public LsWidget
 {
+    Q_OBJECT
 public:
     LsSlideToUnlock(QString name="");
 
@@ -30,8 +32,15 @@ public:
     void applySettings();
 
 private:
-    QPixmap m_SliderImage;
+    int m_UnlockX;
+    int m_UnlockY;
+    LsUnlockSlider* m_Slider;
     QPixmap m_BackgroundImage;
+    QPoint m_SliderInitialPos;
+
+private slots:
+    void onSliderMoveEnded();
+    void onSliderMoved(QPointF);
 };
 
 #endif // LSSLIDETOUNLOCK_H
