@@ -19,6 +19,8 @@
 #include <QApplication>
 #include <QDesktopWidget>
 
+bool LsWidget::m_Portrait;
+
 LsWidget::LsWidget(QString name)
 {
     m_Name = name;
@@ -37,12 +39,7 @@ QVariant LsWidget::getSetting(QString name, QVariant defaultValue)
 
 QPoint LsWidget::getPosSetting(QPoint defaultValue)
 {
-    QString name;
-    if (isPortrait())
-        name = "PosP";
-    else
-        name = "PosL";
-
+    QString name = isPortrait() ? "PosP" : "PosL";
     return getPosSetting(name, defaultValue);
 }
 
@@ -52,7 +49,7 @@ QPoint LsWidget::getPosSetting(QString name, QPoint defaultValue)
     QStringList elem = pos.split(';');
     if (elem.count() == 2){        
 #ifdef Q_WS_MAEMO_5
-        QSize s = QApplication::desktop()->size();
+        QSize s = LsWidget::isPortrait() ? QSize(480, 800) : QSize(800, 480);
 #else
         QSize s(800,480);
 #endif
@@ -83,12 +80,7 @@ QPoint LsWidget::getPosSetting(QString name, QPoint defaultValue)
 
 QSize LsWidget::getSizeSetting(QSize defaultValue)
 {
-    QString name;
-    if (isPortrait())
-        name = "SizeP";
-    else
-        name = "SizeL";
-
+    QString name = isPortrait() ? "SizeP" : "SizeL";
     return getSizeSetting(name, defaultValue);
 }
 
@@ -124,6 +116,11 @@ Qt::AlignmentFlag LsWidget::getAlignmentSetting(QString name, Qt::AlignmentFlag
         return Qt::AlignLeft;
     else if (align == "right")
         return Qt::AlignRight;
+    else if (align == "top")
+        return Qt::AlignTop;
+    else if (align == "bottom")
+        return Qt::AlignBottom;
+
     return defaultValue;
 }
 
@@ -205,7 +202,12 @@ void LsWidget::update()
 
 bool LsWidget::isPortrait()
 {
-    return QApplication::desktop()->width() < QApplication::desktop()->height();
+    return LsWidget::m_Portrait;
+}
+
+void LsWidget::setPortrait(bool portrait)
+{
+    LsWidget::m_Portrait = portrait;
 }
 
 void LsWidget::setSizeAndPosition(QSize defaultSize, QPoint defaultPos)
