@@ -47,6 +47,8 @@ public:
     virtual void applySettings() {}
 
     static bool isPortrait();
+    static void setPortrait(bool);
+
     void setSizeAndPosition(QSize defaultSize, QPoint defaultPos);
     void setName(QString name);
     QString name();
@@ -67,6 +69,8 @@ protected:
     void setSize(QSize);
 
 private:
+    static bool m_Portrait;
+
     QString m_Name;
     QRectF m_Size;
 };
